@@ -153,10 +153,10 @@ class RouteFunction(object):
         finally:
             controller_instance.context = None
 
-    def __str__(self) -> str:
+    def __str__(self) -> str:  # pragma: no cover
         return self.route.route_params.path
 
-    def __repr__(self) -> str:
+    def __repr__(self) -> str:  # pragma: no cover
         if not self.api_controller:
             return f"<RouteFunction, controller: No Controller Found, path: {self.__str__()}>"
         return f"<RouteFunction, controller: {self.api_controller.controller_class.__name__}, path: {self.__str__()}>"
@@ -170,9 +170,11 @@ class AsyncRouteFunction(RouteFunction):
             *args: Any,
             **kwargs: Any,
         ) -> Any:
+            from asgiref.sync import sync_to_async
+
             context = context or cast(RouteContext, service_resolver(RouteContext))
             with self._prep_controller_route_execution(context, **kwargs) as ctx:
-                ctx.controller_instance.check_permissions()
+                await sync_to_async(ctx.controller_instance.check_permissions)()
                 result = await self.route.view_func(
                     ctx.controller_instance, *args, **ctx.view_func_kwargs
                 )
@@ -181,7 +183,7 @@ class AsyncRouteFunction(RouteFunction):
         as_view.get_route_function = lambda: self  # type:ignore
         return as_view
 
-    def __repr__(self) -> str:
+    def __repr__(self) -> str:  # pragma: no cover
         if not self.api_controller:
             return f"<AsyncRouteFunction, controller: No Controller Found, path: {self.__str__()}>"
         return f"<AsyncRouteFunction, controller: {self.api_controller.controller_class.__name__}, path: {self.__str__()}>"
