@@ -11,7 +11,7 @@ def test_with_client(client: Client):
 
     test_item = {"start_date": "2020-01-01", "end_date": "2020-01-02", "title": "test"}
 
-    response = client.post("/api/events/create", **json_payload(test_item))
+    response = client.post("/api/events", **json_payload(test_item))
     assert response.status_code == 201
     assert Event.objects.count() == 1
 
@@ -26,7 +26,9 @@ def test_with_client(client: Client):
 
 def test_reverse():
     # check that url reversing works
-    assert reverse("api-1.0.0:event-create-url-name") == "/api/events/create"
+    assert reverse("api-1.0.0:event-create-url-name") == "/api/events"
+    assert reverse("api-1.0.0:event-list") == "/api/events"
+    assert reverse("api-1.0.0:event-list-2") == "/api/events/list"
 
 
 def json_payload(data):
